# Reference Catalog
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/reference-catalog#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/reference-catalog#benefits)
  * [Available Data](https://help.sap.com/docs/leanix/ea/reference-catalog#available-data)
  * [Fact Sheet Attributes](https://help.sap.com/docs/leanix/ea/reference-catalog#fact-sheet-attributes)


The reference catalog provides reference data for business capabilities, applications, IT components, and tech categories, which enables you to set up and maintain your inventory more efficiently.
